@@ -4,8 +4,11 @@
 import os
 import time
 import string
+import subprocess
+
 import misopy
 import misopy.settings as settings
+import misopy.misc_utils as misc_utils
 from settings import Settings, load_settings
 
 def write_cluster_preface(file_handle):
@@ -35,7 +38,8 @@ def make_bash_script(filename, cmd, crate_dir=None):
     """
 #    os.system('ls %s' %(filename))
     if crate_dir == None:
-        crate_dir = os.path.dirname(os.path.abspath(os.path.expanduser(__file__)))
+        crate_dir = \
+            os.path.dirname(os.path.abspath(os.path.expanduser(__file__)))
     f = open(filename, 'w')
     f.write("#!/bin/bash\n")
     f.write("export PATH=$PATH:%s\n" %(crate_dir))
@@ -47,7 +51,7 @@ def make_bash_script(filename, cmd, crate_dir=None):
     os.system('chmod +x \"%s\"' %(filename))
 
     
-def valid_qsub_name(name):
+def valid_cluster_name(name):
     """
     Return valid qsub ID by removing semicolons, converting
     them into underscores.
@@ -55,6 +59,7 @@ def valid_qsub_name(name):
     name = name.replace(';', '_')
     return name
 
+
 def run_SGEarray_cluster(arg_list, argfile, cluster_output_dir,
                          queue_type="long",
                          cluster_scripts_dir=None,
@@ -67,6 +72,7 @@ def run_SGEarray_cluster(arg_list, argfile, cluster_output_dir,
 
     Function contributed by Michael Lovci, UCSD.
     """
+    misc_utils.make_dir(cluster_output_dir)
     # Create arguments file to pass on to job
     f = open(argfile, 'w')
     nargs = len(arg_list)
@@ -76,24 +82,22 @@ def run_SGEarray_cluster(arg_list, argfile, cluster_output_dir,
         njobs = 1+(nargs/chunk)
     
     for args in arg_list:
-        f.write(args + "\n")
+        f.write(args[0] + "\n")
     f.close()
         
     if cluster_scripts_dir == None:
 	cluster_scripts_dir = os.path.join(cluster_output_dir,
                                            'cluster_scripts')
-    if not os.path.isdir(cluster_scripts_dir):
-	os.mkdir(cluster_scripts_dir)
+    misc_utils.make_dir(cluster_scripts_dir)
     scripts_output_dir = os.path.join(cluster_output_dir,
                                       'scripts_output')
-    if not os.path.isdir(scripts_output_dir):
-	os.mkdir(scripts_output_dir)
+    misc_utils.make_dir(scripts_output_dir)
     scripts_output_dir = os.path.abspath(scripts_output_dir)
     script_error = os.path.join(scripts_output_dir,
                                 string.join([job_name, "err"], "."))
     script_out = os.path.join(scripts_output_dir,
                               string.join([job_name, "out"], "."))
-    cluster_script = os.path.join(cluster_scripts_dir, "run_miso.sh");
+    cluster_script = os.path.join(cluster_scripts_dir, "run_miso.sh")
 
     if settings != None:
         load_settings(settings)
@@ -153,14 +157,17 @@ def run_SGEarray_cluster(arg_list, argfile, cluster_output_dir,
     os.system(qsub_cmd)
 
 
-def run_on_cluster(cmd, job_name, cluster_output_dir, cluster_scripts_dir=None,
-                   queue_type=None, cmd_name="qsub", settings=None):
+def run_on_cluster(cmd, job_name, cluster_output_dir,
+                   cluster_scripts_dir=None,
+                   queue_type=None,
+                   cmd_name="qsub",
+                   settings_fname=None):
     print "Submitting job: %s" %(job_name)
     queue_name = None
 
     # Load command name from settings file
-    if settings != None:
-        load_settings(settings)
+    if settings_fname != None:
+        load_settings(settings_fname)
         cmd_name = Settings.get_cluster_command()
 
     if queue_type == "long":
@@ -171,7 +178,6 @@ def run_on_cluster(cmd, job_name, cluster_output_dir, cluster_scripts_dir=None,
         print "Warning: Unknown queue type: %s" %(queue_type)
         queue_name = queue_type
     
-
     if queue_type == None:
         print "  - queue: unspecified"
     else:
@@ -179,25 +185,118 @@ def run_on_cluster(cmd, job_name, cluster_output_dir, cluster_scripts_dir=None,
                                                      queue_name)
 
     #print "  - cmd: %s" %(cmd)
+    misc_utils.make_dir(cluster_output_dir)
     if cluster_scripts_dir == None:
-	cluster_scripts_dir = os.path.join(cluster_output_dir, 'cluster_scripts')
-	if not os.path.isdir(cluster_scripts_dir):
-	    os.mkdir(cluster_scripts_dir)
-    scripts_output_dir = os.path.join(cluster_output_dir, 'scripts_output')
-    if not os.path.isdir(scripts_output_dir):
-	os.mkdir(scripts_output_dir)
+	cluster_scripts_dir = os.path.join(cluster_output_dir,
+                                           'cluster_scripts')
+        misc_utils.make_dir(cluster_scripts_dir)
+    scripts_output_dir = os.path.join(cluster_output_dir,
+                                      'scripts_output')
+    misc_utils.make_dir(scripts_output_dir)
     scripts_output_dir = os.path.abspath(scripts_output_dir)
-    #qsub_call = 'qsub -V -q \"%s\" -o \"%s\" -e \"%s\"' %(queue_type, scripts_output_dir, scripts_output_dir)
-    qsub_call = '%s -o \"%s\" -e \"%s\"' %(cmd_name, scripts_output_dir,
-                                           scripts_output_dir)
-
+    cluster_call = '%s -o \"%s\" -e \"%s\"' %(cmd_name,
+                                              scripts_output_dir,
+                                              scripts_output_dir)
     # Add queue type if given one
     if queue_name != None:
-        qsub_call += ' -q \"%s\"' %(queue_name)
+        cluster_call += ' -q \"%s\"' %(queue_name)
         
-    script_name = valid_qsub_name(os.path.join(cluster_scripts_dir,
-                                               '%s_time_%s.sh' %(job_name,
-                                                                 time.strftime("%m-%d-%y_%H:%M:%S"))))
+    script_name = \
+        valid_cluster_name(os.path.join(cluster_scripts_dir,
+                                     '%s_time_%s.sh' \
+                                     %(job_name,
+                                       time.strftime("%m-%d-%y_%H:%M:%S"))))
     make_bash_script(script_name, cmd)
-    qsub_cmd = qsub_call + ' \"%s\"' %(script_name)
-    os.system(qsub_cmd)
+    cluster_cmd = cluster_call + ' \"%s\"' %(script_name)
+    job_id = launch_job(cluster_cmd, cmd_name)
+    return job_id
+
+
+def launch_job(cluster_cmd, cmd_name):
+    """
+    Execute cluster_cmd and return its job ID if
+    it can be fetched.
+    """
+    print "Executing: %s" %(cluster_cmd)
+    proc = subprocess.Popen(cluster_cmd, shell=True,
+                            stdout=subprocess.PIPE,
+                            stderr=subprocess.PIPE,
+                            stdin=subprocess.PIPE)
+    # Read the job ID if it's a known cluster
+    # submission system
+    output = proc.communicate()
+    job_id = None
+    if cmd_name == "qsub":
+        if "." in output[0][:-1] and ">" not in output[0]:
+            job_id = int(output[0].split(".")[0])
+    elif cmd_name == "bsub":
+        if "is submitted to" in output[0]:
+            job_id = int(output[0].strip().split()[1][1:-1])                
+    return job_id
+
+
+def wait_on_job(job_id, cluster_cmd,
+                delay=60):
+    """
+    Wait on a job given a job id.
+    """
+    if cluster_cmd == "qsub":
+        # Handle qsub
+        while True:
+            output = \
+                subprocess.Popen("qstat %i" %(job_id),
+                                 shell=True,
+                                 stdout=subprocess.PIPE,
+                                 stderr=subprocess.PIPE).communicate()
+            if "Unknown Job" in output[1]:
+                break
+            time.sleep(delay)
+        time.sleep(delay)
+    elif cluster_cmd == "bsub":
+        # Handle bsub
+        while True:
+            output = subprocess.Popen("bjobs %i" %(job_id),
+                                      shell=True,
+                                      stdout=subprocess.PIPE,
+                                      stderr=subprocess.PIPE).communicate()
+            if len(output[0]) > 0:
+                status = output[0].split()[10]
+                if status == "DONE":
+                    break
+            else:
+                # No jobs available
+                break
+            time.sleep(delay)
+        time.sleep(delay)
+        
+        
+def wait_on_jobs(job_ids, cluster_cmd,
+                 delay=120,
+                 supported_cmds=["qsub",
+                                 "bsub"]):
+    """
+    Wait on a set of job IDs.
+    """
+    if len(job_ids) == 0:
+        return
+    if cluster_cmd not in supported_cmds:
+        return 
+    num_jobs = len(job_ids)
+    print "Waiting on a set of %d jobs..." %(num_jobs)
+    curr_time = time.strftime("%x, %X")
+    t_start = time.time()
+    print "  - Starting to wait at %s" %(curr_time)
+    completed_jobs = {}
+    for job_id in job_ids:
+        if job_id in completed_jobs:
+            continue
+        wait_on_job(job_id, cluster_cmd)
+        print "  - Job ", job_id, " completed."
+        completed_jobs[job_id] = True
+    curr_time = time.strftime("%x, %X")
+    t_end = time.time()
+    print "Jobs completed at %s" %(curr_time)
+    duration = ((t_end - t_start) / 60.) / 60.
+    print "  - Took %.2f hours." %(duration)
+
+    
