@@ -170,35 +170,11 @@ def load_bam_reads(bam_filename,
     """
     print "Loading BAM filename from: %s" %(bam_filename)
     bam_filename = os.path.abspath(os.path.expanduser(bam_filename))
-    t1 = time.time()
     bamfile = pysam.Samfile(bam_filename, "rb",
                             template=template)
-    t2 = time.time()
-    print "Loading took %.2f seconds" %(t2 - t1)
     return bamfile
 
-def fetch_bam_reads_in_region(bamfile, chrom, start, end, gene=None):
-    """
-    Align BAM reads to the gene model.
-    """
-    gene_reads = []
 
-    if chrom in bamfile.references:
-        pass
-    else:
-        chrom = chrom.split("chr")[1]
-        
-    try:
-        gene_reads = bamfile.fetch(chrom, start, end)
-    except ValueError:
-        print "Cannot fetch reads in region: %s:%d-%d" %(chrom,
-                                                         start,
-                                                         end)
-    print "never got here?"
-
-    return gene_reads
-
-    
 def fetch_bam_reads_in_gene(bamfile, chrom, start, end, gene=None):
     """
     Align BAM reads to the gene model.
@@ -208,8 +184,12 @@ def fetch_bam_reads_in_gene(bamfile, chrom, start, end, gene=None):
     if chrom in bamfile.references:
         pass
     else:
-        chrom = chrom.split("chr")[1]
-        
+        chrom_parts = chrom.split("chr")
+        if len(chrom_parts) <= 1:
+            print "Error: chromosome %s must mismatch bamfile %s" \
+                %(chrom, bamfile)
+        chrom = chrom_parts[1]
+
     try:
         gene_reads = bamfile.fetch(chrom, start, end)
     except ValueError:
@@ -234,6 +214,22 @@ def flag_to_strand(flag):
     return "-"
 
 
+def strip_mate_id(read_name):
+    """
+    Strip canonical mate IDs for paired end reads, e.g.
+    
+    #1, #2
+
+    or:
+
+    /1, /2
+    """
+    if read_name.endswith("/1") or read_name.endswith("/2") or \
+       read_name.endswith("#1") or read_name.endswith("#2"):
+        read_name = read_name[0:-3]
+    return read_name
+
+    
 def pair_sam_reads(samfile, filter_reads=True,
                    return_unpaired=False):
     """
@@ -244,6 +240,9 @@ def pair_sam_reads(samfile, filter_reads=True,
 
     for read in samfile:
         curr_name = read.qname
+
+        # Strip canonical mate IDs 
+        curr_name = strip_mate_id(curr_name)
         
         if filter_reads:
             # Skip reads that failed QC or are unmapped
@@ -280,14 +279,15 @@ def pair_sam_reads(samfile, filter_reads=True,
             print "WARNING: %s left mate starts later than right "\
                   "mate" %(left_read.qname)
         num_total += 1
-#            raise Exception, (left_read.qname, left_read.pos, right_read.pos)
 
     # Delete reads that are on the same strand
     for del_key in to_delete:
         del paired_reads[del_key]
 
-    print "Filtered out %d read pairs that were on same strand." %(len(to_delete))
-    print "Filtered out %d reads that had no paired mate." %(num_unpaired)
+    print "Filtered out %d read pairs that were on same strand." \
+        %(len(to_delete))
+    print "Filtered out %d reads that had no paired mate." \
+        %(num_unpaired)
     print "  - Total read pairs: %d" %(num_total)
 
     if not return_unpaired:
@@ -306,40 +306,138 @@ def sam_cigar_to_str(sam_cigar):
     # First element in sam CIGAR list is the CIGAR type
     # (e.g. match or insertion) and the second is
     # the number of nucleotides
-    cigar_str = "".join(["%d%s" %(c[1], CIGAR_TYPES[c[0]]) \
-                         for c in sam_cigar])
+    #cigar_str = "".join(["%d%s" %(c[1], CIGAR_TYPES[c[0]]) \
+    #                     for c in sam_cigar])
+    #### OPTIMIZED VERSION
+    cigar_str = ""
+    for c in sam_cigar:
+        cigar_str += "%d%s" %(c[1], CIGAR_TYPES[c[0]])
     return cigar_str
-    
-def sam_parse_reads(samfile, paired_end=False):
+
+
+def read_matches_strand(read,
+                        target_strand,
+                        strand_rule,
+                        paired_end=None):
+    """
+    Check if a read matches strand.
+
+    - target_strand: the annotation strand ('+' or '-')
+    - strand_rule: the strand rule, i.e.
+      ('fr-unstranded', 'fr-firststrand', or 'fr-secondstrand')
+    """
+    if strand_rule == "fr-unstranded":
+        return True
+    matches = False
+    if paired_end is not None:
+        # Paired-end reads
+        read1, read2 = read
+        if strand_rule == "fr-firststrand":
+            # fr-firststrand: means that the *second* of the mates
+            # must match the strand
+            matches = (flag_to_strand(read2.flag) == target_strand)
+        elif strand_rule == "fr-secondstrand":
+            # fr-secondstrand: means that the *first* of the mates
+            # must match the strand
+            matches = (flag_to_strand(read1.flag) == target_strand)
+        else:
+            raise Exception, "Unknown strandedness rule."
+    else:
+        # Single-end reads
+        if strand_rule == "fr-firststrand":
+            # fr-firststrand: We sequence the first read only, so it must
+            # *NOT* match the target strand
+            matches = (flag_to_strand(read.flag) != target_strand)
+        elif strand_rule == "fr-secondstrand":
+            # fr-secondstrand: We only sequence the first read, which 
+            # is supposed to match the target strand
+            matches = (flag_to_strand(read.flag) == target_strand)
+        else:
+            raise Exception, "Unknown strandedness rule."
+    return matches 
+
+
+def sam_parse_reads(samfile,
+                    paired_end=False,
+                    strand_rule=None,
+                    target_strand=None):
+    """
+    Parse the SAM reads. If paired-end, pair up the mates
+    together.
+
+    Also forces the strandedness convention, discarding
+    reads that do not match the correct strand.
+
+    - strand_rule: specifies the strandedness convention. Can be
+      'fr-unstranded', 'fr-firststrand' or 'fr-secondstrand'.
+    - target_strand: specifies the strand to match, i.e. the
+      annotation strand. Can be '+' or '-'.
+    """
     read_positions = []
     read_cigars = []
     num_reads = 0
-    
+
+    check_strand = True
+    # Determine if we need to check strandedness of reads.
+    # If we're given an unstranded convention, or if we're
+    # not given a target strand, then assume that there's
+    # no need to check strandedness.
+    if (strand_rule is None) or \
+       (strand_rule is "fr-unstranded") or \
+       (target_strand is None):
+        # No need to check strand
+        check_strand = False
+
+    # Track number of reads discarded due to strand
+    # violations, if strand-specific
+    num_strand_discarded = 0
     if paired_end:
         # Pair up the reads 
         paired_reads = pair_sam_reads(samfile)
 
-        # Process them into format required by fastmiso
+        # Process reads into format required by fastmiso
         # MISO C engine requires pairs to follow each other in order.
         # Unpaired reads are not supported.
         for read_id, read_info in paired_reads.iteritems():
+            if check_strand:
+                # Check strand
+                if not read_matches_strand(read_info,
+                                           target_strand,
+                                           strand_rule,
+                                           paired_end=paired_end):
+                    # Skip reads that don't match strand
+                    num_strand_discarded += 1
+                    continue
             read1, read2 = read_info
-            read_positions.extend([int(read1.pos), int(read2.pos)])
-            read_cigars.extend([sam_cigar_to_str(read1.cigar),
-                                sam_cigar_to_str(read2.cigar)])
+            # Read positions and cigar strings are collected
+            read_positions.append(int(read1.pos))
+            read_positions.append(int(read2.pos))
+            read_cigars.append(sam_cigar_to_str(read1.cigar))
+            read_cigars.append(sam_cigar_to_str(read2.cigar))
             num_reads += 1
     else:
         # Single-end
         for read in samfile:
+            if check_strand:
+                if not read_matches_strand(read,
+                                           target_strand,
+                                           strand_rule,
+                                           paired_end=paired_end):
+                    # Skip reads that don't match strand
+                    num_strand_discarded += 1
+                    continue
             read_positions.append(int(read.pos))
             read_cigars.append(sam_cigar_to_str(read.cigar))
             num_reads += 1
 
+    if check_strand:
+        print "No. reads discarded due to strand violation: %d" \
+            %(num_strand_discarded)
+
     reads = (tuple(read_positions),
              tuple(read_cigars))
 
     return reads, num_reads
-
     
 
 def sam_pe_reads_to_isoforms(samfile, gene, read_len, overhang_len):
