@@ -187,9 +187,6 @@ def plot_density(sashimi_obj, pickle_filename, event):
     tx_start, tx_end, exon_starts, exon_ends, gene_obj, mRNAs, strand, chrom = \
         parseGene(pickle_filename, event)
 
-    print "exon starts: ", exon_starts
-    print "exon ends: ", exon_ends
-
     # Get the right scalings
     graphcoords, graphToGene = getScaling(tx_start, tx_end, strand,
                                           exon_starts, exon_ends, intron_scale,
@@ -221,6 +218,7 @@ def plot_density(sashimi_obj, pickle_filename, event):
         sample_label = settings["sample_labels"][i]
 
         print "Reading sample label: %s" %(sample_label)
+        print "Processing BAM: %s" %(bam_file)
         
         plotted_ax = plot_density_single(settings, sample_label,
                                          tx_start, tx_end, gene_obj, mRNAs, strand,
