@@ -301,7 +301,7 @@ int splicing_miso_paired(const splicing_gff_t *gff, size_t gene,
     SPLICING_CHECK(splicing_vector_init(&vfragmentProb, 0));
     SPLICING_FINALLY(splicing_vector_destroy, &vfragmentProb);
     SPLICING_CHECK(splicing_normal_fragment(normalMean, normalVar, numDevs,
-					    2*readLength, myfragmentProb,
+					    readLength, myfragmentProb,
 					    &fragmentStart));
     splicing_vector_scale(myfragmentProb, 
 			  1.0/splicing_vector_sum(myfragmentProb));
@@ -445,6 +445,7 @@ int splicing_miso_paired(const splicing_gff_t *gff, size_t gene,
 						  psi, noiso, noChains, 
 						  fragmentStart,
 						  &vass));
+  printf("no chains: %d\n", noChains);
   
   /* foreach Iteration m=1, ..., M do */
 
@@ -519,8 +520,7 @@ int splicing_miso_paired(const splicing_gff_t *gff, size_t gene,
     noS=0;
     noIterations = 3*noIterations - 2*noBurnIn;
     noBurnIn = m;
-    rundata->noSamples = noSamples = 
-      noChains * (noIterations - noBurnIn) / noLag;
+    noSamples = noChains * (noIterations - noBurnIn) / noLag;
     lagCounter = 0;
 
     SPLICING_CHECK(splicing_matrix_resize(samples, noiso, noSamples));
@@ -563,6 +563,14 @@ int splicing_miso_paired(const splicing_gff_t *gff, size_t gene,
     SPLICING_FINALLY_CLEAN(1);
   }
 
+  /* We always return the same number of samples. */
+
+  if (rundata->noSamples != noSamples) {
+    splicing_vector_remove_section(logLik, 0, noSamples-rundata->noSamples);
+    splicing_matrix_remove_cols_section(samples, 0,
+					noSamples-rundata->noSamples);
+  }
+
   return 0;
 }
 
